@@ -88,42 +88,43 @@ createImageSeq <- function (moviepath='Movies',imagepath='ImageSequences',
         paste("    movieName, movieExtension = os.path.splitext(filename)"),
         paste("    try:"),
         paste("        targetDirName = string.translate(subprocess.check_output",
-              "(['",exiftoolpath,"', '-DateTimeOriginal', '-T', os.path.join(",
-              "movieDir, filename)]).split()[0], None, ':') + '_' + movieName",
-               sep=''),
+              "(['",exiftoolpath,"', '-DateTimeOriginal', '-T', ",
+              "os.path.join(movieDir, ",
+              "filename)]).split()[0], None, ':') + '_' + movieName",sep=''),
         paste("    except Exception:"),
-        paste("        print 'Error in obtaining date in file %s; therefore",
-              "skipped' % filename"),
-        paste("        continue"),
+        paste("        print 'Error in obtaining date in file %s; creating ",
+              "directory name without date' % filename", sep=''),
+        paste("        targetDirName = 'nodate_'+ movieName"),
         paste("    try:"),
-        paste("        duration = float(string.translate(subprocess.check_",
-              "output(['",exiftoolpath,"', '-n', '-s3', '-duration', ",
-              "os.path.join(movieDir, filename)]).split()[0], None, ':'))",
-               sep=''),
+        paste("        duration = float(string.translate(",
+              "subprocess.check_output(",
+              "['",exiftoolpath,"', '-n', '-s3', '-duration', ",
+              "os.path.join(movieDir, ",
+              "filename)]).split()[0], None, ':'))",sep=''),
         paste("    except Exception:"),
-        paste("        print 'Error in obtaining duration movie in file %s,",
-              "therefore skipped' % filename"),
-        paste("        continue"),
-        paste("    if os.path.exists(os.path.join(sequenceParentDir,",
-              "targetDirName)):"),
-        paste("        print 'Directory %s already exists, file %s skipped' %",
-              "(targetDirName, filename)"),
+        paste("        print 'Error in obtaining duration movie in file %s, ",
+              "converting up to 10 seconds from start' % filename",sep=''),
+        paste("        duration = 10"),
+        paste("    if os.path.exists(os.path.join(sequenceParentDir, ",
+              "targetDirName)):",sep=''),
+        paste("        print 'Directory %s already exists, file %s skipped'",
+              " % (targetDirName, filename)",sep=''),
         paste("    else:"),
-        paste("        if duration >",nsec,":",sep=''),
+        paste("        if duration > 100:"),
         paste("            start = duration/2 -",nsec/2,sep=''),
         paste("            stop = duration/2 +",nsec/2,sep=''),
         paste("        else:"),
         paste("            start = 0"),
         paste("            stop = duration"),
         paste("        os.mkdir(os.path.join(sequenceParentDir, targetDirName))"),
-        paste("        command = conv_command(filename, targetDirName, start,",
-              "stop)"),
+        paste("        command = conv_command(filename, targetDirName, start, ",
+              "stop)",sep=''),
         paste("        try:"),
         paste("            subprocess.call(command)"),
         paste("            print 'File %s done' % filename"),
         paste("        except Exception, e:"),
-        paste("            print 'Error in processing file %s, error: %s' %",
-              "(filename, e)")
+        paste("            print 'Error in processing file %s, ",
+              "error: %s' % (filename, e)",sep='')
     ), fileConn, sep = "\n")
 
     close(fileConn) 
